@@ -46,7 +46,7 @@ sp_tables_i <- tibble::tribble(~table_num, ~report_num, ~id,   ~table_code,   ~d
 #' Get path to a CSV file containing a table.
 #'
 #' This is normally called inside `sp_get_table()` but can be used separately if
-#' finer-grained control of intermediate outputs is needed, e.g. in a {targets} workflow.
+#' finer-grained control of intermediate outputs is needed, e.g. in a `{targets}` workflow.
 #'
 #' @param table_id Table ID; see `id` column in `sp_tables` for a list of available codelists.
 #' @param dataset_path Path to downloaded dataset, as output by `sp_get_dataset()`
@@ -88,7 +88,7 @@ sp_get_table_file <- function(table_id, dataset_path, reunzip = FALSE) {
 #' Load a statnipokladna table from a CSV file
 #'
 #' This is normally called inside `sp_get_table()` but can be used separately if
-#' finer-grained control of intermediate outputs is needed, e.g. in a {targets} workflow.
+#' finer-grained control of intermediate outputs is needed, e.g. in a `{targets}` workflow.
 #'
 #' @param path path to a CSV file, as output by `sp_get_table_file()`.
 #' @param ico Organisation ID to filter by, if supplied.
@@ -106,12 +106,20 @@ sp_load_table <- function(path, ico = NULL) {
 
   suppressWarnings(suppressMessages(
     dt <- readr::read_csv2(path, col_types = readr::cols(.default = readr::col_character()))))
+
+  dt_new_names <- stringr::str_remove_all(names(dt), "\"[A-\\u017da-\\u017e\\s\\-\\./]*\"") |>
+    stringr::str_remove_all("/BIC/")
+
+  dt <- dt %>%
+    purrr::set_names(dt_new_names)
+
   # print(head(dt))
   if(max(stringr::str_length(dt$`ZC_ICO:ZC_ICO`), na.rm = TRUE) == 10) {
     dt <- dplyr::mutate(dt, `ZC_ICO:ZC_ICO` = stringr::str_sub(.data$`ZC_ICO:ZC_ICO`, 3, 10))
   }
   if(!is.null(ico)) dt <- dt[dt$`ZC_ICO:ZC_ICO` %in% ico,]
-  dt <- dt %>%
+
+  dt <- dt |>
     purrr::set_names(stringr::str_remove(names(dt), "^[A-Z_0-9/]*:")) %>%
     dplyr::mutate_at(dplyr::vars(dplyr::starts_with("ZU_")), ~switch_minus(.) %>% as.numeric(.)) %>%
     tidyr::extract(.data$`0FISCPER`, c("vykaz_year", "vykaz_month"), "([0-9]{4})0([0-9]{2})") %>%
